'use strict';

/**
 * A helper for locales
 *
 * @memberof HashBrown.Common.Service
 */
class LocaleService {
    /**
     * Gets the name of a locale
     *
     * @param {String} locale
     *
     * @return {String} Name
     */
    static getLocaleName(locale) {
        checkParam(locale, 'locale', String, true);

        let all = this.getLocaleOptions(true);

        for(let name in all) {
            if(all[name] !== locale) { continue; }

            return name;
        }

        return locale;
    }

    /**
     * Gets all locales
     *
     * @param {Boolean} includeNames
     *
     * @returns {Object} List of locale names
     */
    static getLocaleOptions(includeNames = false) {
        let locales = {
            'Afrikaans (Namibia)': 'af_NA',
            'Afrikaans (South Africa)': 'af_ZA',
            'Afrikaans': 'af',
            'Akan (Ghana)': 'ak_GH',
            'Akan': 'ak',
            'Albanian (Albania)': 'sq_AL',
            'Albanian': 'sq',
            'Amharic (Ethiopia)': 'am_ET',
            'Amharic': 'am',
            'Arabic (Algeria)': 'ar_DZ',
            'Arabic (Bahrain)': 'ar_BH',
            'Arabic (Egypt)': 'ar_EG',
            'Arabic (Iraq)': 'ar_IQ',
            'Arabic (Jordan)': 'ar_JO',
            'Arabic (Kuwait)': 'ar_KW',
            'Arabic (Lebanon)': 'ar_LB',
            'Arabic (Libya)': 'ar_LY',
            'Arabic (Morocco)': 'ar_MA',
            'Arabic (Oman)': 'ar_OM',
            'Arabic (Qatar)': 'ar_QA',
            'Arabic (Saudi Arabia)': 'ar_SA',
            'Arabic (Sudan)': 'ar_SD',
            'Arabic (Syria)': 'ar_SY',
            'Arabic (Tunisia)': 'ar_TN',
            'Arabic (United Arab Emirates)': 'ar_AE',
            'Arabic (Yemen)': 'ar_YE',
            'Arabic': 'ar',
            'Armenian (Armenia)': 'hy_AM',
            'Armenian': 'hy',
            'Assamese (India)': 'as_IN',
            'Assamese': 'as',
            'Asu (Tanzania)': 'asa_TZ',
            'Asu': 'asa',
            'Azerbaijani (Cyrillic)': 'az_Cyrl',
            'Azerbaijani (Cyrillic, Azerbaijan)': 'az_Cyrl_AZ',
            'Azerbaijani (Latin)': 'az_Latn',
            'Azerbaijani (Latin, Azerbaijan)': 'az_Latn_AZ',
            'Azerbaijani': 'az',
            'Bambara (Mali)': 'bm_ML',
            'Bambara': 'bm',
            'Basque (Spain)': 'eu_ES',
            'Basque': 'eu',
            'Belarusian (Belarus)': 'be_BY',
            'Belarusian': 'be',
            'Bemba (Zambia)': 'bem_ZM',
            'Bemba': 'bem',
            'Bena (Tanzania)': 'bez_TZ',
            'Bena': 'bez',
            'Bengali (Bangladesh)': 'bn_BD',
            'Bengali (India)': 'bn_IN',
            'Bengali': 'bn',
            'Bosnian (Bosnia and Herzegovina)': 'bs_BA',
            'Bosnian': 'bs',
            'Bulgarian (Bulgaria)': 'bg_BG',
            'Bulgarian': 'bg',
            'Burmese (Myanmar [Burma])': 'my_MM',
            'Burmese': 'my',
            'Cantonese (Traditional, Hong Kong)': 'yue_Hant_HK',
            'Catalan (Spain)': 'ca_ES',
            'Catalan': 'ca',
            'Central Morocco Tamazight (Latin)': 'tzm_Latn',
            'Central Morocco Tamazight (Latin, Morocco)': 'tzm_Latn_MA',
            'Central Morocco Tamazight': 'tzm',
            'Cherokee (United States)': 'chr_US',
            'Cherokee': 'chr',
            'Chiga (Uganda)': 'cgg_UG',
            'Chiga': 'cgg',
            'Chinese (Simplified Han)': 'zh_Hans',
            'Chinese (Simplified Han, China)': 'zh_Hans_CN',
            'Chinese (Simplified Han, Hong Kong)': 'zh_Hans_HK',
            'Chinese (Simplified Han, Macau)': 'zh_Hans_MO',
            'Chinese (Simplified Han, Singapore)': 'zh_Hans_SG',
            'Chinese (Traditional Han)': 'zh_Hant',
            'Chinese (Traditional Han, Hong Kong)': 'zh_Hant_HK',
            'Chinese (Traditional Han, Macau)': 'zh_Hant_MO',
            'Chinese (Traditional Han, Taiwan)': 'zh_Hant_TW',
            'Chinese': 'zh',
            'Cornish (United Kingdom)': 'kw_GB',
            'Cornish': 'kw',
            'Croatian (Croatia)': 'hr_HR',
            'Croatian': 'hr',
            'Czech (Czech Republic)': 'cs_CZ',
            'Czech': 'cs',
            'Danish (Denmark)': 'da_DK',
            'Danish': 'da',
            'Dutch (Belgium)': 'nl_BE',
            'Dutch (Netherlands)': 'nl_NL',
            'Dutch': 'nl',
            'Embu (Kenya)': 'ebu_KE',
            'Embu': 'ebu',
            'English (American Samoa)': 'en_AS',
            'English (Australia)': 'en_AU',
            'English (Belgium)': 'en_BE',
            'English (Belize)': 'en_BZ',
            'English (Botswana)': 'en_BW',
            'English (Canada)': 'en_CA',
            'English (Guam)': 'en_GU',
            'English (Hong Kong)': 'en_HK',
            'English (India)': 'en_IN',
            'English (Ireland)': 'en_IE',
            'English (Israel)': 'en_IL',
            'English (Jamaica)': 'en_JM',
            'English (Malta)': 'en_MT',
            'English (Marshall Islands)': 'en_MH',
            'English (Mauritius)': 'en_MU',
            'English (Namibia)': 'en_NA',
            'English (New Zealand)': 'en_NZ',
            'English (Northern Mariana Islands)': 'en_MP',
            'English (Pakistan)': 'en_PK',
            'English (Philippines)': 'en_PH',
            'English (Singapore)': 'en_SG',
            'English (South Africa)': 'en_ZA',
            'English (Trinidad and Tobago)': 'en_TT',
            'English (U.S. Minor Outlying Islands)': 'en_UM',
            'English (U.S. Virgin Islands)': 'en_VI',
            'English (United Kingdom)': 'en_GB',
            'English (United States)': 'en_US',
            'English (Zimbabwe)': 'en_ZW',
            'English': 'en',
            'Esperanto': 'eo',
            'Estonian (Estonia)': 'et_EE',
            'Estonian': 'et',
            'Ewe (Ghana)': 'ee_GH',
            'Ewe (Togo)': 'ee_TG',
            'Ewe': 'ee',
            'Faroese (Faroe Islands)': 'fo_FO',
            'Faroese': 'fo',
            'Filipino (Philippines)': 'fil_PH',
            'Filipino': 'fil',
            'Finnish (Finland)': 'fi_FI',
            'Finnish': 'fi',
            'French (Belgium)': 'fr_BE',
            'French (Benin)': 'fr_BJ',
            'French (Burkina Faso)': 'fr_BF',
            'French (Burundi)': 'fr_BI',
            'French (Cameroon)': 'fr_CM',
            'French (Canada)': 'fr_CA',
            'French (Central African Republic)': 'fr_CF',
            'French (Chad)': 'fr_TD',
            'French (Comoros)': 'fr_KM',
            'French (Congo - Brazzaville)': 'fr_CG',
            'French (Congo - Kinshasa)': 'fr_CD',
            'French (Côte d’Ivoire)': 'fr_CI',
            'French (Djibouti)': 'fr_DJ',
            'French (Equatorial Guinea)': 'fr_GQ',
            'French (France)': 'fr_FR',
            'French (Gabon)': 'fr_GA',
            'French (Guadeloupe)': 'fr_GP',
            'French (Guinea)': 'fr_GN',
            'French (Luxembourg)': 'fr_LU',
            'French (Madagascar)': 'fr_MG',
            'French (Mali)': 'fr_ML',
            'French (Martinique)': 'fr_MQ',
            'French (Monaco)': 'fr_MC',
            'French (Niger)': 'fr_NE',
            'French (Rwanda)': 'fr_RW',
            'French (Réunion)': 'fr_RE',
            'French (Saint Barthélemy)': 'fr_BL',
            'French (Saint Martin)': 'fr_MF',
            'French (Senegal)': 'fr_SN',
            'French (Switzerland)': 'fr_CH',
            'French (Togo)': 'fr_TG',
            'French': 'fr',
            'Fulah (Senegal)': 'ff_SN',
            'Fulah': 'ff',
            'Galician (Spain)': 'gl_ES',
            'Galician': 'gl',
            'Ganda (Uganda)': 'lg_UG',
            'Ganda': 'lg',
            'Georgian (Georgia)': 'ka_GE',
            'Georgian': 'ka',
            'German (Austria)': 'de_AT',
            'German (Belgium)': 'de_BE',
            'German (Germany)': 'de_DE',
            'German (Liechtenstein)': 'de_LI',
            'German (Luxembourg)': 'de_LU',
            'German (Switzerland)': 'de_CH',
            'German': 'de',
            'Greek (Cyprus)': 'el_CY',
            'Greek (Greece)': 'el_GR',
            'Greek': 'el',
            'Gujarati (India)': 'gu_IN',
            'Gujarati': 'gu',
            'Gusii (Kenya)': 'guz_KE',
            'Gusii': 'guz',
            'Hausa (Latin)': 'ha_Latn',
            'Hausa (Latin, Ghana)': 'ha_Latn_GH',
            'Hausa (Latin, Niger)': 'ha_Latn_NE',
            'Hausa (Latin, Nigeria)': 'ha_Latn_NG',
            'Hausa': 'ha',
            'Hawaiian (United States)': 'haw_US',
            'Hawaiian': 'haw',
            'Hebrew (Israel)': 'he_IL',
            'Hebrew': 'he',
            'Hindi (India)': 'hi_IN',
            'Hindi': 'hi',
            'Hungarian (Hungary)': 'hu_HU',
            'Hungarian': 'hu',
            'Icelandic (Iceland)': 'is_IS',
            'Icelandic': 'is',
            'Igbo (Nigeria)': 'ig_NG',
            'Igbo': 'ig',
            'Indonesian (Indonesia)': 'id_ID',
            'Indonesian': 'id',
            'Irish (Ireland)': 'ga_IE',
            'Irish': 'ga',
            'Italian (Italy)': 'it_IT',
            'Italian (Switzerland)': 'it_CH',
            'Italian': 'it',
            'Japanese (Japan)': 'ja_JP',
            'Japanese': 'ja',
            'Kabuverdianu (Cape Verde)': 'kea_CV',
            'Kabuverdianu': 'kea',
            'Kabyle (Algeria)': 'kab_DZ',
            'Kabyle': 'kab',
            'Kalaallisut (Greenland)': 'kl_GL',
            'Kalaallisut': 'kl',
            'Kalenjin (Kenya)': 'kln_KE',
            'Kalenjin': 'kln',
            'Kamba (Kenya)': 'kam_KE',
            'Kamba': 'kam',
            'Kannada (India)': 'kn_IN',
            'Kannada': 'kn',
            'Kazakh (Cyrillic)': 'kk_Cyrl',
            'Kazakh (Cyrillic, Kazakhstan)': 'kk_Cyrl_KZ',
            'Kazakh': 'kk',
            'Khmer (Cambodia)': 'km_KH',
            'Khmer': 'km',
            'Kikuyu (Kenya)': 'ki_KE',
            'Kikuyu': 'ki',
            'Kinyarwanda (Rwanda)': 'rw_RW',
            'Kinyarwanda': 'rw',
            'Konkani (India)': 'kok_IN',
            'Konkani': 'kok',
            'Korean (South Korea)': 'ko_KR',
            'Korean': 'ko',
            'Koyra Chiini (Mali)': 'khq_ML',
            'Koyra Chiini': 'khq',
            'Koyraboro Senni (Mali)': 'ses_ML',
            'Koyraboro Senni': 'ses',
            'Langi (Tanzania)': 'lag_TZ',
            'Langi': 'lag',
            'Latvian (Latvia)': 'lv_LV',
            'Latvian': 'lv',
            'Lithuanian (Lithuania)': 'lt_LT',
            'Lithuanian': 'lt',
            'Luo (Kenya)': 'luo_KE',
            'Luo': 'luo',
            'Luyia (Kenya)': 'luy_KE',
            'Luyia': 'luy',
            'Macedonian (Macedonia)': 'mk_MK',
            'Macedonian': 'mk',
            'Machame (Tanzania)': 'jmc_TZ',
            'Machame': 'jmc',
            'Makonde (Tanzania)': 'kde_TZ',
            'Makonde': 'kde',
            'Malagasy (Madagascar)': 'mg_MG',
            'Malagasy': 'mg',
            'Malay (Brunei)': 'ms_BN',
            'Malay (Malaysia)': 'ms_MY',
            'Malay': 'ms',
            'Malayalam (India)': 'ml_IN',
            'Malayalam': 'ml',
            'Maltese (Malta)': 'mt_MT',
            'Maltese': 'mt',
            'Manx (United Kingdom)': 'gv_GB',
            'Manx': 'gv',
            'Marathi (India)': 'mr_IN',
            'Marathi': 'mr',
            'Masai (Kenya)': 'mas_KE',
            'Masai (Tanzania)': 'mas_TZ',
            'Masai': 'mas',
            'Meru (Kenya)': 'mer_KE',
            'Meru': 'mer',
            'Morisyen (Mauritius)': 'mfe_MU',
            'Morisyen': 'mfe',
            'Nama (Namibia)': 'naq_NA',
            'Nama': 'naq',
            'Nepali (India)': 'ne_IN',
            'Nepali (Nepal)': 'ne_NP',
            'Nepali': 'ne',
            'North Ndebele (Zimbabwe)': 'nd_ZW',
            'North Ndebele': 'nd',
            'Norwegian Bokmål (Norway)': 'nb_NO',
            'Norwegian Bokmål': 'nb',
            'Norwegian Nynorsk (Norway)': 'nn_NO',
            'Norwegian Nynorsk': 'nn',
            'Nyankole (Uganda)': 'nyn_UG',
            'Nyankole': 'nyn',
            'Oriya (India)': 'or_IN',
            'Oriya': 'or',
            'Oromo (Ethiopia)': 'om_ET',
            'Oromo (Kenya)': 'om_KE',
            'Oromo': 'om',
            'Pashto (Afghanistan)': 'ps_AF',
            'Pashto': 'ps',
            'Persian (Afghanistan)': 'fa_AF',
            'Persian (Iran)': 'fa_IR',
            'Persian': 'fa',
            'Polish (Poland)': 'pl_PL',
            'Polish': 'pl',
            'Portuguese (Brazil)': 'pt_BR',
            'Portuguese (Guinea-Bissau)': 'pt_GW',
            'Portuguese (Mozambique)': 'pt_MZ',
            'Portuguese (Portugal)': 'pt_PT',
            'Portuguese': 'pt',
            'Punjabi (Arabic)': 'pa_Arab',
            'Punjabi (Arabic, Pakistan)': 'pa_Arab_PK',
            'Punjabi (Gurmukhi)': 'pa_Guru',
            'Punjabi (Gurmukhi, India)': 'pa_Guru_IN',
            'Punjabi': 'pa',
            'Romanian (Moldova)': 'ro_MD',
            'Romanian (Romania)': 'ro_RO',
            'Romanian': 'ro',
            'Romansh (Switzerland)': 'rm_CH',
            'Romansh': 'rm',
            'Rombo (Tanzania)': 'rof_TZ',
            'Rombo': 'rof',
            'Russian (Moldova)': 'ru_MD',
            'Russian (Russia)': 'ru_RU',
            'Russian (Ukraine)': 'ru_UA',
            'Russian': 'ru',
            'Rwa (Tanzania)': 'rwk_TZ',
            'Rwa': 'rwk',
            'Samburu (Kenya)': 'saq_KE',
            'Samburu': 'saq',
            'Sango (Central African Republic)': 'sg_CF',
            'Sango': 'sg',
            'Sena (Mozambique)': 'seh_MZ',
            'Sena': 'seh',
            'Serbian (Cyrillic)': 'sr_Cyrl',
            'Serbian (Cyrillic, Bosnia and Herzegovina)': 'sr_Cyrl_BA',
            'Serbian (Cyrillic, Montenegro)': 'sr_Cyrl_ME',
            'Serbian (Cyrillic, Serbia)': 'sr_Cyrl_RS',
            'Serbian (Latin)': 'sr_Latn',
            'Serbian (Latin, Bosnia and Herzegovina)': 'sr_Latn_BA',
            'Serbian (Latin, Montenegro)': 'sr_Latn_ME',
            'Serbian (Latin, Serbia)': 'sr_Latn_RS',
            'Serbian': 'sr',
            'Shona (Zimbabwe)': 'sn_ZW',
            'Shona': 'sn',
            'Sichuan Yi (China)': 'ii_CN',
            'Sichuan Yi': 'ii',
            'Sinhala (Sri Lanka)': 'si_LK',
            'Sinhala': 'si',
            'Slovak (Slovakia)': 'sk_SK',
            'Slovak': 'sk',
            'Slovenian (Slovenia)': 'sl_SI',
            'Slovenian': 'sl',
            'Soga (Uganda)': 'xog_UG',
            'Soga': 'xog',
            'Somali (Djibouti)': 'so_DJ',
            'Somali (Ethiopia)': 'so_ET',
            'Somali (Kenya)': 'so_KE',
            'Somali (Somalia)': 'so_SO',
            'Somali': 'so',
            'Spanish (Argentina)': 'es_AR',
            'Spanish (Bolivia)': 'es_BO',
            'Spanish (Chile)': 'es_CL',
            'Spanish (Colombia)': 'es_CO',
            'Spanish (Costa Rica)': 'es_CR',
            'Spanish (Dominican Republic)': 'es_DO',
            'Spanish (Ecuador)': 'es_EC',
            'Spanish (El Salvador)': 'es_SV',
            'Spanish (Equatorial Guinea)': 'es_GQ',
            'Spanish (Guatemala)': 'es_GT',
            'Spanish (Honduras)': 'es_HN',
            'Spanish (Latin America)': 'es_419',
            'Spanish (Mexico)': 'es_MX',
            'Spanish (Nicaragua)': 'es_NI',
            'Spanish (Panama)': 'es_PA',
            'Spanish (Paraguay)': 'es_PY',
            'Spanish (Peru)': 'es_PE',
            'Spanish (Puerto Rico)': 'es_PR',
            'Spanish (Spain)': 'es_ES',
            'Spanish (United States)': 'es_US',
            'Spanish (Uruguay)': 'es_UY',
            'Spanish (Venezuela)': 'es_VE',
            'Spanish': 'es',
            'Swahili (Kenya)': 'sw_KE',
            'Swahili (Tanzania)': 'sw_TZ',
            'Swahili': 'sw',
            'Swedish (Finland)': 'sv_FI',
            'Swedish (Sweden)': 'sv_SE',
            'Swedish': 'sv',
            'Swiss German (Switzerland)': 'gsw_CH',
            'Swiss German': 'gsw',
            'Tachelhit (Latin)': 'shi_Latn',
            'Tachelhit (Latin, Morocco)': 'shi_Latn_MA',
            'Tachelhit (Tifinagh)': 'shi_Tfng',
            'Tachelhit (Tifinagh, Morocco)': 'shi_Tfng_MA',
            'Tachelhit': 'shi',
            'Taita (Kenya)': 'dav_KE',
            'Taita': 'dav',
            'Tamil (India)': 'ta_IN',
            'Tamil (Sri Lanka)': 'ta_LK',
            'Tamil': 'ta',
            'Telugu (India)': 'te_IN',
            'Telugu': 'te',
            'Teso (Kenya)': 'teo_KE',
            'Teso (Uganda)': 'teo_UG',
            'Teso': 'teo',
            'Thai (Thailand)': 'th_TH',
            'Thai': 'th',
            'Tibetan (China)': 'bo_CN',
            'Tibetan (India)': 'bo_IN',
            'Tibetan': 'bo',
            'Tigrinya (Eritrea)': 'ti_ER',
            'Tigrinya (Ethiopia)': 'ti_ET',
            'Tigrinya': 'ti',
            'Tonga (Tonga)': 'to_TO',
            'Tonga': 'to',
            'Turkish (Turkey)': 'tr_TR',
            'Turkish': 'tr',
            'Ukrainian (Ukraine)': 'uk_UA',
            'Ukrainian': 'uk',
            'Urdu (India)': 'ur_IN',
            'Urdu (Pakistan)': 'ur_PK',
            'Urdu': 'ur',
            'Uzbek (Arabic)': 'uz_Arab',
            'Uzbek (Arabic, Afghanistan)': 'uz_Arab_AF',
            'Uzbek (Cyrillic)': 'uz_Cyrl',
            'Uzbek (Cyrillic, Uzbekistan)': 'uz_Cyrl_UZ',
            'Uzbek (Latin)': 'uz_Latn',
            'Uzbek (Latin, Uzbekistan)': 'uz_Latn_UZ',
            'Uzbek': 'uz',
            'Vietnamese (Vietnam)': 'vi_VN',
            'Vietnamese': 'vi',
            'Vunjo (Tanzania)': 'vun_TZ',
            'Vunjo': 'vun',
            'Welsh (United Kingdom)': 'cy_GB',
            'Welsh': 'cy',
            'Yoruba (Nigeria)': 'yo_NG',
            'Yoruba': 'yo',
            'Zulu (South Africa)': 'zu_ZA',
            'Zulu': 'zu'
        };

        if(includeNames) {
            return locales;
        }

        return Object.values(locales);
    }
}

module.exports = LocaleService;
